#
# spec file for package python-pingparsing
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pingparsing
Version:        1.4.2
Release:        2.1
Summary:        CLI-tool/Python-library for parsing ping command output
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/thombashi/pingparsing
Source:         https://github.com/thombashi/pingparsing/archive/v%{version}.tar.gz#/pingparsing-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 38.3.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-humanreadable >= 0.3
Requires:       python-loguru >= 0.4.1
Requires:       python-pyparsing >= 2.0.3
Requires:       python-pytz >= 2018.9
Requires:       python-setuptools >= 38.3.0
Requires:       python-simplejson
Requires:       python-subprocrunner >= 1.2.2
Requires:       python-typepy >= 1.3.2
Requires(post): alts
Requires(postun): alts
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module humanreadable >= 0.3}
BuildRequires:  %{python_module pyparsing >= 2.0.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz >= 2018.9}
BuildRequires:  %{python_module simplejson}
BuildRequires:  %{python_module subprocrunner >= 1.2.2}
BuildRequires:  %{python_module typepy >= 1.3.2}
# /SECTION
%python_subpackages

%description
pingparsing is a CLI-tool/Python-library for parsing ping command output.

%prep
%autosetup -p1 -n pingparsing-%{version}
sed -i -e '/^#!\//, 1d' pingparsing/__main__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pingparsing
%python_expand rm -rf %{buildroot}%{$python_sitelib}/examples
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative pingparsing

%postun
%python_uninstall_alternative pingparsing

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/pingparsing
%{python_sitelib}/pingparsing*

%changelog
* Tue Jun  3 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.2:
  * Add `docs` extras
  * Add `__all__` to `__init__.py`
  * Add a build and publish workflow
  * Add Sigstore signatures to release assets
  * Update dependencies in requirements files
  * Bump minimum version of `typepy` to `1.3.2`
  * Bump minimum version of `humanreadable` to `0.3`
  * Add support for Python 3.12
  * Drop support for Python 3.6
  * Improve type annotations
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Fix Pygemnts requirement in setup.py
  * Change the output of the CLI logger to stderr
  * Add support for Python 3.11
  * Update help messages
  * Update requirements
- drop fix-requirements.patch (upstream)
* Mon Feb 13 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-requirements.patch:
  * Fix invalid version number.
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.0
  * Drop support for Python 3.5
  * Add support for pyparsing v3
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.2
  * Fix parsing when ping results with pipe field.
* Sun May 16 2021 Matej Cepl <mcepl@suse.com>
- Actually depends on subprocrunner >= 1.2.2 (and thus on
  sr#893494)
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.1
  * Change PingTransmitter.ping_option accepts Sequence
  * Fix a problem that --interface option value is not properly
    applied to ping commands
* Sun Mar 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.0
  * Add packet size in icmp_replies
  * Add received addresses in icmp_replies
  * Fix incorrect parsing of domain destination with '.net' suffix
  * Modify a type annotation of PingParserInterface.parse method
  * Improve parsing precision of times
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  * Add support for Python 3.10
  * Add --timezone option to the CLI
  * Add time zone support for parser classes
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.0
  * Make it possible to parse ping timeouts includes timestamps.
  * Add --addopts option to the CLI.
  * Add -O option to ping execution when --timestamp option is
    specified on Linux.
  * Set default serializer for timestamps of ICMP replies.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sun Apr 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.3
  * Fix type annotations
* Sat Apr  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.2
  * Make it possible execute the CLI with python -m pingparsing
  * Update requirements
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.0.1
  * minor metadata fixes
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.0
  * Drop Python 2 support
  * Add packet size option to PingTransmitter and CLI
  * Add ttl option to PingTransmitter and CLI
  * Add include_icmp_replies flag to PingStats.as_dict method
  * Add --no-color option to the CLI tool
  * Add type annotations and py.typed to the package
  * Add [cli] extras_require
  * Update dependencies
  * Remove deprecated methods
  * Reduce a package dependency
  * Replace the logging library
  * Fix timestamp parsing when transmitting ping by CLI
  * Minor bug fixes
* Sat Feb  8 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.18.2
